classdef Result < handle
    % RESULT Result obtained from a simulation with Rotare.
    %   This class defines the Result object that can be used to store the solution an entire Rotare
    %   simulation.
    %
    % Notes:
    %   - Almost all properties are private to prevent accidental overwriting.
    %
    % -----
    %
    % Result properties:
    %   leishman - Results obtained with the leishman solver
    %   indfact  - Results obtained with the indFact solver
    %   indvel   - Results obtained with the indVel solver
    %   stahlhut - Results obtained with the stalhlut solver
    %   operPts  - Table with the operating points for each individual result
    %
    %
    % Result methods:
    %
    % Result constructor:
    %   Result = Result() creates an empty object.
    %
    % Constructor inputs:
    %
    % See also: Rotor, rotare, template, af_tools.Airfoil.
    %
    % <a href="https:/gitlab.uliege.be/rotare/documentation">Complete documentation (online)</a>

    % ----------------------------------------------------------------------------------------------
    % FIXME: Make plot methods to compare two results easily
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/rotare/rotare
    % Docs: https://gitlab.uliege.be/rotare/documentation
    % Issues: https://gitlab.uliege.be/rotare/rotare/-/issues
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Base properties of the elements
    properties
        leishman (1, :) OperRotor  % Results obtained with the leishman solver
        indfact (1, :) OperRotor   % Results obtained with the indFact solver
        indvel (1, :) OperRotor    % Results obtained with the indVel solver
        stahlhut (1, :) OperRotor  % Results obtained with the stalhlut solver
        operPts (:, 4) table      % Table of operating points for each individual result
    end

    methods

        function self = Result()
            % Result Constructor.
            %   Creates the Result object.
            %
            % Currently empty on purpose. Results are to be assigned manually.
        end

    end
end
